==> kv5500-0.3.tar.gz: kv5500-0.3/src/kv5500_photo.hpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_PHOTO_H
#define KV5500_PHOTO_H

#include "kv5500_file.hpp"

namespace KV5500 {

    class PhotoInfoScanner : public FileInfoScanner {
    public:
        PhotoInfoScanner();

    private:
        PhotoInfoScanner(const PhotoInfoScanner&);
        PhotoInfoScanner& operator=(const PhotoInfoScanner&);
    };

    class PhotoGetFileScanner : public GetFileScanner {
    public:
        PhotoGetFileScanner(unsigned int num);

    private:
        PhotoGetFileScanner(const PhotoGetFileScanner&);
        PhotoGetFileScanner& operator=(const PhotoGetFileScanner&);

        std::string GetFilename() const;
    };

    bool GetPhotoInfo(std::vector<FileInfo>& vec);
    bool SavePhotoFile(unsigned int num);
}

#endif

==> kv5500-0.3.1.tar.gz: kv5500-0.3.1/src/kv5500_photo.hpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_PHOTO_H
#define KV5500_PHOTO_H

#include "kv5500_file.hpp"

namespace KV5500 {

    struct PhotoInfo {
        static const char numReqTempl_[5];
        static const char nameReqTempl_[6];
        static const char sizeReqTempl_[8];

        static const char prepareReqTempl_[5];
        static const char transReqTempl_[9];
    };

    typedef FileInfoScanner<PhotoInfo> PhotoInfoScanner;

    struct PhotoFilenameGenerator {
        static std::string GetFilename(unsigned int num);
    };

    typedef GetFileScanner<PhotoInfo, PhotoFilenameGenerator, ConsoleDisplay> PhotoGetFileScanner;

    bool GetPhotoInfo(std::vector<FileInfo>& vec);
    bool SavePhotoFile(unsigned int num);
}

#endif
